==> xbox-smartglass-rest-0.9.4.tar.gz: xbox-smartglass-rest-0.9.4/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup


setup(
    name="xbox-smartglass-rest",
    version="0.9.4",
    author="OpenXbox",
    description="Xbox One Smartglass REST API",
    long_description=open('README.rst').read() + '\n\n' + open('HISTORY.rst').read(),
    license="GPL",
    keywords="xbox one smartglass rest api",
    url="https://github.com/OpenXbox/xbox-smartglass-rest-python",
    packages=[
        'xbox.rest',
        'xbox.rest.routes',
        'xbox.rest.scripts'
    ],
    namespace_packages=['xbox'],
    zip_safe=False,
    include_package_data=True,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6"
    ],
    install_requires=[
        'xbox-smartglass-stump==0.9.3',
        'Flask'
    ],
    tests_require=[
        'pytest',
        'flake8',
        'tox'
    ],
    extras_require={
        'dev': [
            'bumpversion',
            'watchdog',
            'coverage',
            'Sphinx',
            'wheel',
            'twine'
        ]
    },
    test_suite="tests",
    entry_points={
        'console_scripts': [
            'xbox-rest-server=xbox.rest.scripts.rest_server:main'
        ]
    }
)

==> xbox-smartglass-rest-0.9.5.tar.gz: xbox-smartglass-rest-0.9.5/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup


setup(
    name="xbox-smartglass-rest",
    version="0.9.5",
    author="OpenXbox",
    description="Xbox One Smartglass REST API",
    long_description=open('README.rst').read() + '\n\n' + open('HISTORY.rst').read(),
    license="GPL",
    keywords="xbox one smartglass rest api",
    url="https://github.com/OpenXbox/xbox-smartglass-rest-python",
    packages=[
        'xbox.rest',
        'xbox.rest.routes',
        'xbox.rest.scripts'
    ],
    namespace_packages=['xbox'],
    zip_safe=False,
    include_package_data=True,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6"
    ],
    install_requires=[
        'xbox-smartglass-stump>=0.9.4',
        'Flask'
    ],
    tests_require=[
        'pytest',
        'flake8',
        'tox'
    ],
    extras_require={
        'dev': [
            'bumpversion',
            'watchdog',
            'coverage',
            'Sphinx',
            'wheel',
            'twine'
        ]
    },
    test_suite="tests",
    entry_points={
        'console_scripts': [
            'xbox-rest-server=xbox.rest.scripts.rest_server:main'
        ]
    }
)
